==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached.md <==
# AmazonElastiCacheElastiCacheForMemcached


```text
aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached
```

```text
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')
```



| Illustration | AmazonElastiCacheElastiCacheForMemcached | AmazonElastiCacheElastiCacheForMemcachedCard | AmazonElastiCacheElastiCacheForMemcachedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached.png) | ![illustration for AmazonElastiCacheElastiCacheForMemcached](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached.Local.png) | ![illustration for AmazonElastiCacheElastiCacheForMemcachedCard](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcachedCard.Local.png) | ![illustration for AmazonElastiCacheElastiCacheForMemcachedGroup](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcachedGroup.Local.png) |




## AmazonElastiCacheElastiCacheForMemcached

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcached
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcached('AmazonElastiCacheElastiCacheForMemcached', 'Amazon Elasti Cache Elasti Cache For Memcached', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcached
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcached('AmazonElastiCacheElastiCacheForMemcached', 'Amazon Elasti Cache Elasti Cache For Memcached', 'an optional tech label')
@enduml
```

## AmazonElastiCacheElastiCacheForMemcachedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedCard
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedCard('AmazonElastiCacheElastiCacheForMemcachedCard', 'Amazon Elasti Cache Elasti Cache For Memcached Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedCard
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedCard('AmazonElastiCacheElastiCacheForMemcachedCard', 'Amazon Elasti Cache Elasti Cache For Memcached Card', 'an optional description')
@enduml
```

## AmazonElastiCacheElastiCacheForMemcachedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedGroup('AmazonElastiCacheElastiCacheForMemcachedGroup', 'Amazon Elasti Cache Elasti Cache For Memcached Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedGroup('AmazonElastiCacheElastiCacheForMemcachedGroup', 'Amazon Elasti Cache Elasti Cache For Memcached Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached.md <==
# AmazonElastiCacheElastiCacheForMemcached


```text
aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached
```

```text
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')
```



| Illustration | AmazonElastiCacheElastiCacheForMemcached | AmazonElastiCacheElastiCacheForMemcachedCard | AmazonElastiCacheElastiCacheForMemcachedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached.png) | ![illustration for AmazonElastiCacheElastiCacheForMemcached](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached.Local.png) | ![illustration for AmazonElastiCacheElastiCacheForMemcachedCard](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcachedCard.Local.png) | ![illustration for AmazonElastiCacheElastiCacheForMemcachedGroup](../../../aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcachedGroup.Local.png) |




## AmazonElastiCacheElastiCacheForMemcached

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcached
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcached('AmazonElastiCacheElastiCacheForMemcached', 'Amazon Elasti Cache Elasti Cache For Memcached', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcached
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcached('AmazonElastiCacheElastiCacheForMemcached', 'Amazon Elasti Cache Elasti Cache For Memcached', 'an optional tech label')
@enduml
```

## AmazonElastiCacheElastiCacheForMemcachedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedCard
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedCard('AmazonElastiCacheElastiCacheForMemcachedCard', 'Amazon Elasti Cache Elasti Cache For Memcached Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedCard
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedCard('AmazonElastiCacheElastiCacheForMemcachedCard', 'Amazon Elasti Cache Elasti Cache For Memcached Card', 'an optional description')
@enduml
```

## AmazonElastiCacheElastiCacheForMemcachedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedGroup('AmazonElastiCacheElastiCacheForMemcachedGroup', 'Amazon Elasti Cache Elasti Cache For Memcached Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheElastiCacheForMemcachedGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheElastiCacheForMemcached')

' renders the element
AmazonElastiCacheElastiCacheForMemcachedGroup('AmazonElastiCacheElastiCacheForMemcachedGroup', 'Amazon Elasti Cache Elasti Cache For Memcached Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
